import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixFunctionsV1BuilderlessProduction from './functions-v1-builderless-production-function-builderless-productions.http.js';
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Creates FunctionBuilderlessProduction
 * @internal
 * @documentationMaturity preview
 * @requiredField options.functionBuilderlessProduction.formTemplateExtensionId
 * @requiredField options.functionBuilderlessProduction.formValue
 * @requiredField options.functionBuilderlessProduction.functionTemplateExtensionId
 * @permissionId FUNCTIONS.FUNCTION_BUILDERLESS_PRODUCTION_CREATE
 * @returns Created Function builderless production
 * @fqn wix.functions.builderlessproductions.v1.FunctionBuilderlessProductions.CreateFunctionBuilderlessProduction
 */
export async function createFunctionBuilderlessProduction(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        functionBuilderlessProduction: options?.functionBuilderlessProduction,
    });
    const reqOpts = ambassadorWixFunctionsV1BuilderlessProduction.createFunctionBuilderlessProduction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)
            ?.functionBuilderlessProduction;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                functionBuilderlessProduction: '$[0].functionBuilderlessProduction',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Gets FunctionBuilderlessProduction
 * @param functionId - Id of the function of the requested builderless production
 * @internal
 * @documentationMaturity preview
 * @requiredField functionId
 * @permissionId FUNCTIONS.FUNCTION_BUILDERLESS_PRODUCTION_READ
 * @returns The requested Function builderless production
 * @fqn wix.functions.builderlessproductions.v1.FunctionBuilderlessProductions.GetFunctionBuilderlessProduction
 */
export async function getFunctionBuilderlessProduction(functionId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        functionId: functionId,
    });
    const reqOpts = ambassadorWixFunctionsV1BuilderlessProduction.getFunctionBuilderlessProduction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)
            ?.functionBuilderlessProduction;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { functionId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['functionId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Updates FunctionBuilderlessProduction
 * @param _id - Id, which is a function id
 * @internal
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField options.functionBuilderlessProduction.formTemplateExtensionId
 * @requiredField options.functionBuilderlessProduction.formValue
 * @permissionId FUNCTIONS.FUNCTION_BUILDERLESS_PRODUCTION_UPDATE
 * @returns Updated Function builderless production
 * @fqn wix.functions.builderlessproductions.v1.FunctionBuilderlessProductions.UpdateFunctionBuilderlessProduction
 */
export async function updateFunctionBuilderlessProduction(_id, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        functionBuilderlessProduction: {
            ...options?.functionBuilderlessProduction,
            id: _id,
        },
    });
    const reqOpts = ambassadorWixFunctionsV1BuilderlessProduction.updateFunctionBuilderlessProduction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)
            ?.functionBuilderlessProduction;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {
                functionBuilderlessProduction: '$[1].functionBuilderlessProduction',
            },
            explicitPathsToArguments: {
                'functionBuilderlessProduction.id': '$[0]',
            },
            singleArgumentUnchanged: false,
        }, ['_id', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Deletes FunctionBuilderlessProduction
 * @param functionId - Id of the builderless production id, which is a function id
 * @internal
 * @documentationMaturity preview
 * @requiredField functionId
 * @permissionId FUNCTIONS.FUNCTION_BUILDERLESS_PRODUCTION_DELETE
 * @fqn wix.functions.builderlessproductions.v1.FunctionBuilderlessProductions.DeleteFunctionBuilderlessProduction
 */
export async function deleteFunctionBuilderlessProduction(functionId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        functionId: functionId,
    });
    const reqOpts = ambassadorWixFunctionsV1BuilderlessProduction.deleteFunctionBuilderlessProduction(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { functionId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['functionId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=functions-v1-builderless-production-function-builderless-productions.universal.js.map